/* ****************************************************************************
 * Copyright 2019 Open Systems Development BV                                 *
 *                                                                            *
 * Permission is hereby granted, free of charge, to any person obtaining a    *
 * copy of this software and associated documentation files (the "Software"), *
 * to deal in the Software without restriction, including without limitation  *
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,   *
 * and/or sell copies of the Software, and to permit persons to whom the      *
 * Software is furnished to do so, subject to the following conditions:       *
 *                                                                            *
 * The above copyright notice and this permission notice shall be included in *
 * all copies or substantial portions of the Software.                        *
 *                                                                            *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR *
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,   *
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL    *
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER *
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING    *
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER        *
 * DEALINGS IN THE SOFTWARE.                                                  *
 * ***************************************************************************/
#ifndef OSDEV_COMPONENTS_PINGER_H
#define OSDEV_COMPONENTS_PINGER_H

#include <QObject>
#include <QString>
#include <QProcess>

#include "pingdataqueue.h"

namespace osdev {
namespace components {

class PingRunner : public QObject
{
    Q_OBJECT

public:
    PingRunner( QObject *parent = nullptr );
    PingRunner( PingDataQueue *l_shrBuffer, QObject *parent = nullptr );
    virtual ~PingRunner();

    PingRunner( const PingRunner& ) = delete;
    PingRunner( const PingRunner&& ) = delete;
    PingRunner& operator=( const PingRunner& ) = delete;
    PingRunner& operator=( const PingRunner&& ) = delete;

    void startPing( const QString &host_to_ping );

    void setSharedBuffer( PingDataQueue *l_shrBuffer );

private:
    void connectProcess();

private:
    PingDataQueue   *m_shrBuf;
    QString          m_host_to_ping;

};

}           /* End namespace components */
}           /* End namespace osdev  */

#endif      /* OSDEV_COMPONENTS_PINGER_H */
